@@ -413,7 +413,7 @@ class AugWrapper(nn.Module):
 norm_class = nn.BatchNorm2d
 
 def upsample(scale_factor = 2):
-    return nn.Upsample(scale_factor = scale_factor, mode = 'bilinear', align_corners = False)
+    return nn.Upsample(scale_factor = scale_factor)
 
 # squeeze excitation classes
 
